@@ -2,12 +2,11 @@ from einops.layers.torch import Rearrange as _Rearrange
 
 from tensorneko_util.util import AbstractServer, dispatch, AverageMeter
 from tensorneko_util.util.fp import Seq, AbstractSeq, curry, Some, Empty, F, Stream, return_option, Option, _, __
-from tensorneko_util.util.func import generate_inf_seq, listdir, with_printed, ifelse, dict_add, as_list, \
-    identity, list_to_dict
 from . import type
 from .configuration import Configuration
-from .func import reduce_dict_by, summarize_dict_by, with_printed_shape, is_bad_num, count_parameters, compose
-from .func import tensorneko_path as get_tensorneko_path
+from .func import reduce_dict_by, summarize_dict_by, with_printed_shape, is_bad_num, count_parameters, compose, \
+    generate_inf_seq, listdir, with_printed, ifelse, dict_add, as_list, identity, list_to_dict
+from .func import get_tensorneko_path
 from .ref import ref
 from .reproducibility import Seed
 from .string_getter import get_activation, get_loss
